#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Normalized Volatility Indicator as seen in August 2010's issue of S&C
    /// </summary>
    [Description("Normalized Volatility Indicator as seen in August 2010's issue of S&C")]
    public class NVI : Indicator
    {
        #region Variables
		private int atrPeriod = 64;
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.Blue, PlotStyle.Line, "NVI"));
            Overlay				= false;
            PriceTypeSupported	= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
            Plot0.Set(ATR(AtrPeriod)[0] / Close[0] * 100);
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plot0
        {
            get { return Values[0]; }
        }

        [Description("Numbers of bars used for calculations")]
        [Category("Parameters")]
        public int AtrPeriod
        {
            get { return atrPeriod; }
            set { atrPeriod = Math.Max(1, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private NVI[] cacheNVI = null;

        private static NVI checkNVI = new NVI();

        /// <summary>
        /// Normalized Volatility Indicator as seen in August 2010's issue of S&C
        /// </summary>
        /// <returns></returns>
        public NVI NVI(int atrPeriod)
        {
            return NVI(Input, atrPeriod);
        }

        /// <summary>
        /// Normalized Volatility Indicator as seen in August 2010's issue of S&C
        /// </summary>
        /// <returns></returns>
        public NVI NVI(Data.IDataSeries input, int atrPeriod)
        {
            checkNVI.AtrPeriod = atrPeriod;
            atrPeriod = checkNVI.AtrPeriod;

            if (cacheNVI != null)
                for (int idx = 0; idx < cacheNVI.Length; idx++)
                    if (cacheNVI[idx].AtrPeriod == atrPeriod && cacheNVI[idx].EqualsInput(input))
                        return cacheNVI[idx];

            NVI indicator = new NVI();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.AtrPeriod = atrPeriod;
            indicator.SetUp();

            NVI[] tmp = new NVI[cacheNVI == null ? 1 : cacheNVI.Length + 1];
            if (cacheNVI != null)
                cacheNVI.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheNVI = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Normalized Volatility Indicator as seen in August 2010's issue of S&C
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.NVI NVI(int atrPeriod)
        {
            return _indicator.NVI(Input, atrPeriod);
        }

        /// <summary>
        /// Normalized Volatility Indicator as seen in August 2010's issue of S&C
        /// </summary>
        /// <returns></returns>
        public Indicator.NVI NVI(Data.IDataSeries input, int atrPeriod)
        {
            return _indicator.NVI(input, atrPeriod);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Normalized Volatility Indicator as seen in August 2010's issue of S&C
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.NVI NVI(int atrPeriod)
        {
            return _indicator.NVI(Input, atrPeriod);
        }

        /// <summary>
        /// Normalized Volatility Indicator as seen in August 2010's issue of S&C
        /// </summary>
        /// <returns></returns>
        public Indicator.NVI NVI(Data.IDataSeries input, int atrPeriod)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.NVI(input, atrPeriod);
        }

    }
}
#endregion
