#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Strategy;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// S&C magazine August 2010. Using the Normalized Volatility Indicator to determine entry points and direction
    /// </summary>
    [Description("S&C magazine August 2010. Using the Normalized Volatility Indicator to determine entry points and direction")]
    public class NVI_Strategy : Strategy
    {
        #region Variables
		private double	x			= 1.343;
		private int		atrPeriod	= 64;
        #endregion

        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose = true;
			EntryHandling		= EntryHandling.UniqueEntries;
			ExitOnClose			= false;
			Add(NVI(AtrPeriod));
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (NVI(AtrPeriod)[0] < X)
				EnterLong(DefaultQuantity, CurrentBar.ToString());	

			else if (NVI(AtrPeriod)[0] > X)
				EnterShort(DefaultQuantity, CurrentBar.ToString());
        }

        #region Properties
        [Description("Value to test for entry. Optimization is from 1 to 1.5, with step .001")]
        [Category("Parameters")]
        public double X
        {
            get { return x; }
            set { x = Math.Max(1, value); }
        }
		
		[Description("Period for ATR calculation. Default is 64")]
        [Category("Parameters")]
        public int AtrPeriod
        {
            get { return atrPeriod; }
            set { atrPeriod = Math.Max(1, value); }
        }
        #endregion
    }
}
